@@ -1,8 +1,8 @@
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from django.contrib.localflavor.us.models import USStateField
-from django.contrib.localflavor.us.models import PhoneNumberField
-from django.contrib.localflavor.us.us_states import USPS_CHOICES
+from localflavor.us.models import USStateField
+from localflavor.us.models import PhoneNumberField
+from localflavor.us.us_states import USPS_CHOICES
 from resources.models.organizations import Organization
 from resources.models.people import Person
 
